==> eclipse-linuxtools_1.2.1+dfsg.orig.tar.xz: eclipse-linuxtools-1.2.1+dfsg/lttng/org.eclipse.linuxtools.tmf.ui.tests/src/org/eclipse/linuxtools/tmf/ui/tests/views/uml2sd/loader/Uml2SDTestTimestamp.java <==
/*******************************************************************************
 * Copyright (c) 2011, 2012 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *******************************************************************************/
package org.eclipse.linuxtools.tmf.ui.tests.views.uml2sd.loader;

import org.eclipse.linuxtools.tmf.core.event.TmfTimestamp;

/**
 * Timestamp implementation for UML2SD test cases.
 *
 * @author Bernd Hufmann
 *
 */
public class Uml2SDTestTimestamp extends TmfTimestamp {
    // ------------------------------------------------------------------------
    // Attributes
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Constructors
    // ------------------------------------------------------------------------

    /**
     * Constructor
     * @param value time as long value (nanoseconds)
     */
    public Uml2SDTestTimestamp(long value) {
        super(value, IUml2SDTestConstants.TIME_SCALE);
    }

    // ------------------------------------------------------------------------
    // Operations
    // ------------------------------------------------------------------------

}

==> eclipse-linuxtools_3.1.0.orig.tar.xz: eclipse-linuxtools-3.1.0/lttng/org.eclipse.linuxtools.tmf.ui.tests/src/org/eclipse/linuxtools/tmf/ui/tests/views/uml2sd/loader/Uml2SDTestTimestamp.java <==
/*******************************************************************************
 * Copyright (c) 2011, 2013 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *******************************************************************************/
package org.eclipse.linuxtools.tmf.ui.tests.views.uml2sd.loader;

import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestamp;

/**
 * Timestamp implementation for UML2SD test cases.
 *
 * @author Bernd Hufmann
 *
 */
public class Uml2SDTestTimestamp extends TmfTimestamp {
    // ------------------------------------------------------------------------
    // Attributes
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Constructors
    // ------------------------------------------------------------------------

    /**
     * Constructor
     * @param value time as long value (nanoseconds)
     */
    public Uml2SDTestTimestamp(long value) {
        super(value, IUml2SDTestConstants.TIME_SCALE);
    }

    // ------------------------------------------------------------------------
    // Operations
    // ------------------------------------------------------------------------

}
